# flutter_firebase_extra
Manage user auth in minutes.
This package uses ([provider package](https://pub.dev/packages/provider))


## AUTH Basic ussage

1. ([Add firebase to your flutter app](https://firebase.google.com/docs/flutter/setup))

2. Your app must be a child of 'ChangeNotifierProvider'

```flutter
void main() => runApp(MyApp());

class MyApp extends StatelessWidget {
  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider<AuthState>(
      child: MaterialApp(
        home: ParentPage(),
      ),
      create: (_) => AuthState(),
    );
  }
}
```

3. The parent page manages the screen shown in each of the authentication states

```flutter
class ParentPage extends StatelessWidget{
  @override
  Widget build(BuildContext context) {
    return AuthManagerWidget(
      splashScreen: MySplashScreen(), //optional
      introductionScreen: MyIntroductionScreen(), //optional, user not logged
      loginScreen: MyLoginScreen(), // user not logged, the introduction has been completed
      mainScreen: MyMainScreen(), // user logged (email, google, apple or anonymous)
    );
  }
}
```

4. Set introduction as completed

```flutter
AuthState authState = Provider.of(context);
```

```flutter
authState.setIntroductionCompleted(true);
```

5. Prebuilt LoginScreen

```flutter
LoginScreen(
        backgroundColor: Colors.purple,
        expandedWidget: Center(child: Container(height: 200, width: 300, color: Colors.red,),),
        emailLogin: (context){
          return EmailLoginScreen(
            appBar: AppBar(
              title: Text("MyApp Login"),
            ),
            mainColor: Colors.blue,
            privacyUrl: "https://www.myprivacyurl.com",
            termsUrl: "https://mytermsurl.com",
          );
        },
      )
```

5. Logout 
```flutter
AuthState authState = Provider.of(context);
```

```flutter
authState.signOut();
```
