import 'package:apple_sign_in/apple_sign_in_button.dart';
import 'package:flutter/material.dart';
import 'package:flutter_firebase_extra/auth/buttons/email_sign_in_button.dart';
import 'package:provider/provider.dart';
import 'package:shimmer/shimmer.dart';
import 'states/auth_state.dart';
import 'buttons/google_sign_in_button.dart';

class LoginScreen extends StatefulWidget {
  final bool logInWithGoogle, logInWithApple, logInAnonymous;
  final bool darkMode;
  final Color backgroundColor;
  final Widget backgroundWidget, expandedWidget;

  final WidgetBuilder emailLogin;

  const LoginScreen({
    Key key,
    this.emailLogin,
    this.logInWithGoogle = true,
    this.logInWithApple = true,
    this.logInAnonymous = true,
    this.darkMode = false,
    this.backgroundColor,
    this.backgroundWidget,
    this.expandedWidget,
  }) : super(key: key);

  @override
  State<StatefulWidget> createState() => _LoginScreenState();
}

class _LoginScreenState extends State<LoginScreen> {
  bool supportsAppleSignIn = false;
  bool loading = false;

  @override
  Widget build(BuildContext context) {
    AuthState authState = Provider.of<AuthState>(context);
    authState.supportsAppleSignIn().then((value) {
      setState(() {
        supportsAppleSignIn = value;
      });
    });

    Widget rowO = Row(
      mainAxisAlignment: MainAxisAlignment.center,
      children: <Widget>[
        Container(
          width: 30,
          child: Divider(
            thickness: 1,
            color: Colors.white,
          ),
        ),
        Container(
          padding: EdgeInsets.only(left: 16, right: 16),
          child: Text(
            "o",
            style: TextStyle(color: Colors.white),
          ),
        ),
        Container(
          width: 30,
          child: Divider(
            thickness: 1,
            color: Colors.white,
          ),
        ),
      ],
    );

    return SafeArea(
      child: Scaffold(
        backgroundColor: widget.backgroundColor,
        body: Stack(
          alignment: Alignment.topCenter,
          children: <Widget>[
            if (widget.backgroundWidget != null) widget.backgroundWidget,
            Column(
              children: <Widget>[
                Expanded(
                  child: widget.expandedWidget != null
                      ? widget.expandedWidget
                      : Container(),
                ),
                if (widget.emailLogin != null)
                  Container(
                    width: 300,
                    height: 40,
                    margin: EdgeInsets.only(
                        left: 16, right: 16, top: 8, bottom: 16),
                    child: EmailSignInButton(
                      buttonColor: Colors.green,
                      text: "Acceder con email",
                      onPressed: () {
                        Navigator.push(
                          context,
                          MaterialPageRoute(builder: widget.emailLogin),
                        );
                      },
                    ),
                  ),
                if (widget.logInWithGoogle)
                  Container(
                    width: 300,
                    height: 40,
                    margin: EdgeInsets.only(
                        left: 16, right: 16, top: 8, bottom: 16),
                    child: GoogleSignInButton(
                      onPressed: () async {
                        setState(() {
                          loading = true;
                        });
                        var user = await authState.signInGoogle();
                        loading = false;
                        if (user == null) {
                          setState(() {});
                        }
                      },
                      darkMode: widget.darkMode,
                      text: "Acceder con Google",
                    ),
                  ),
                if (widget.logInWithApple && supportsAppleSignIn)
                  Container(
                    width: 300,
                    height: 40,
                    margin: EdgeInsets.only(
                        left: 16, right: 16, top: 8, bottom: 16),
                    child: AppleSignInButton(
                      style: widget.darkMode
                          ? ButtonStyle.black
                          : ButtonStyle.white,
                      type: ButtonType.continueButton,
                      onPressed: () async {
                        setState(() {
                          loading = true;
                        });
                        var user = await authState.signInApple();
                        loading = false;
                        if (user == null) {
                          setState(() {});
                        }
                      },
                    ),
                  ),
                if (widget.logInAnonymous) rowO,
                if (widget.logInAnonymous)
                  Container(
                    width: 300,
                    child: FlatButton(
                      onPressed: () async {
                        setState(() {
                          loading = true;
                        });
                        await authState.signInAnonymous();
                        setState(() {
                          loading = false;
                        });
                      },
                      child: Text(
                        "Continuar sin registrarme",
                        style: TextStyle(color: Colors.white),
                      ),
                    ),
                  ),
              ],
            ),
            loading
                ? Shimmer.fromColors(
                    child: Container(
                      height: 6,
                      color: Colors.white,
                    ),
                    baseColor: Theme.of(context).primaryColor,
                    highlightColor: Colors.white,
                    period: Duration(milliseconds: 750),
                  )
                : Container()
          ],
        ),
        resizeToAvoidBottomInset: false,
      ),
    );
  }
}
